import { Readable } from 'stream';

type Dict<T> = Record<string, T | undefined>;

type HTTPAlias = 'get' | 'post' | 'put' | 'patch' | 'delete';

interface RequestOptions {
  headers?: Dict<unknown>;
  body?: Dict<unknown>;
  query?: Dict<unknown>;
  method?: HTTPAlias;
  timeout?: number;
  compress?: boolean;
  followRedirects?: boolean;
}

interface Options extends RequestOptions {
  url: string;
}

declare const request: <T>(options: Options) => Promise<T>;

declare const streamRequest: (options: Options) => Promise<Readable>;

export { request, streamRequest };
